@@ -6,12 +6,11 @@ use warnings;
 use base 'Exporter';
 use POSIX;
 use Date::Parse;
-use DateTime::Format::Strptime;
 
 our @EXPORT = qw(expand_string missing_values expand_stringi);
 our @EXPORT_OK = qw(expand_hash);
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 my %special =
 (
@@ -197,6 +196,8 @@ Returns undef if there are unexpanded templates left, otherwise true.
 
 =item Curt Tilmes
 
+=item Jeremy Mates (thirg, JMATES)
+
 =back
 
 =head1 SEE ALSO
